@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from typing import Set, Iterator, Any, IO
+
 import sys
 from decimal import Decimal
 import datetime
@@ -8,12 +10,14 @@ import re
 
 import mt940
 from mt940.tags import StatementASNB
+from mt940.models import Transaction, Transactions
 
-from ofxstatement import plugin, parser
+from ofxstatement.plugin import Plugin as BasePlugin
+from ofxstatement.parser import StatementParser as BaseStatementParser
 from ofxstatement.statement import StatementLine, BankAccount
 from ofxstatement.statement import generate_unique_transaction_id
 
-from ofxstatement.plugins.nl.statement import Statement
+from ofxstatement.plugins.statement import Statement
 
 # Need Python 3 for super() syntax
 assert sys.version_info[0] >= 3, "At least Python 3 is required."
@@ -21,7 +25,7 @@ assert sys.version_info[0] >= 3, "At least Python 3 is required."
 logger = logging.getLogger(__name__)
 
 
-def get_bank_id(bank_code: str):
+def get_bank_id(bank_code: str) -> str:
     bic_codes = {'ASN': 'ASNBNL21',
                  'MBANK': 'BREXPLPW',
                  'ABNAMRO': 'ABNANL2A',
@@ -33,47 +37,26 @@ def get_bank_id(bank_code: str):
     return bic_codes[bank_code.upper()]
 
 
-class Plugin(plugin.Plugin):
-    """MT940, text
-    """
+class Parser(BaseStatementParser):
+    unique_id_set: Set[str]
 
-    def get_file_object_parser(self, fh):
-        bank_code = 'ASN'
-        bank_id = None
-        if self.settings is None:
-            pass
-        else:
-            if 'bank_code' in self.settings:
-                bank_code = self.settings.get('bank_code')
-            if 'bank_id' in self.settings:
-                bank_id = self.settings.get('bank_id')
-
-        if bank_id is None:
-            bank_id = get_bank_id(bank_code)
-
-        parser = Parser(fh, bank_code, bank_id)
-        return parser
-
-    def get_parser(self, filename):
-        return self.get_file_object_parser(open(filename, "r"))
-
-
-class Parser(parser.StatementParser):
-    def __init__(self, fin, bank_code, bank_id):
+    def __init__(self, fin: IO[str], bank_code: str, bank_id: str, ignore_check_end_date: bool = False) -> None:
         super().__init__()
-        self.statement = Statement(bank_id=bank_id)  # My Statement()
+        self.statement = Statement(bank_id=bank_id,
+                                   ignore_check_end_date=ignore_check_end_date)
         self.fin = fin
         self.bank_code = bank_code.upper()
+        self.ignore_check_end_date = ignore_check_end_date
         self.unique_id_set = set()
 
-    def parse(self):
+    def parse(self) -> Statement:
         """Main entry point for parsers
 
         super() implementation will call to split_records and parse_record to
         process the file.
         """
 
-        stmt = super().parse()
+        stmt: Statement = super().parse()
 
         logger.debug('trs.data:\n' + pformat(self.trs.data, indent=4))
 
@@ -93,7 +76,7 @@ class Parser(parser.StatementParser):
 
         return stmt
 
-    def split_records(self):
+    def split_records(self) -> Iterator[Any]:
         """Return iterable object consisting of a line per transaction
         """
         data = self.fin.read()
@@ -103,12 +86,12 @@ class Parser(parser.StatementParser):
         if self.bank_code == 'ASN' or bank_id == get_bank_id('ASN'):
             # mt940/tree/develop/mt940_tests/test_tags.py
             tag_parser = StatementASNB()
-            self.trs = mt940.models.Transactions(tags={
+            self.trs = Transactions(tags={
                 tag_parser.id: tag_parser
             })
         elif self.bank_code == 'MBANK' or bank_id == get_bank_id('MBANK'):
             # mt940/tree/develop/mt940_tests/test_processors.py
-            self.trs = mt940.models.Transactions(processors=dict(
+            self.trs = Transactions(processors=dict(
                 post_transaction_details=[
                     mt940.processors.mBank_set_transaction_code,
                     mt940.processors.mBank_set_iph_id,
@@ -116,13 +99,13 @@ class Parser(parser.StatementParser):
                 ],
             ))
         else:
-            self.trs = mt940.models.Transactions()
+            self.trs = Transactions()
 
         self.trs.parse(data)
         for transaction in self.trs:
             yield transaction
 
-    def parse_record(self, transaction):
+    def parse_record(self, transaction: Transaction) -> StatementLine:
         """Parse given transaction line and return StatementLine object
         """
         logger.debug('transaction:\n' + pformat(transaction, indent=4))
@@ -166,3 +149,31 @@ optionally followed by a minus and a counter: '{}'".format(stmt_line.id)
                                 acct_id=bank_account_to)
 
         return stmt_line
+
+
+class Plugin(BasePlugin):
+    """MT940, text
+    """
+
+    def get_file_object_parser(self, fh: IO[str]) -> Parser:
+        bank_code = 'ASN'
+        bank_id = None
+        ignore_check_end_date = False
+        if self.settings is None:
+            pass
+        else:
+            if 'bank_code' in self.settings:
+                bank_code = self.settings.get('bank_code')
+            if 'bank_id' in self.settings:
+                bank_id = self.settings.get('bank_id')
+            if 'ignore_check_end_date' in self.settings:
+                ignore_check_end_date = (self.settings.get('ignore_check_end_date').lower() == 'true')
+
+        if bank_id is None:
+            bank_id = get_bank_id(bank_code)
+
+        parser = Parser(fh, bank_code, bank_id, ignore_check_end_date)
+        return parser
+
+    def get_parser(self, filename: str) -> Parser:
+        return self.get_file_object_parser(open(filename, "r"))
